@@ -13,9 +13,9 @@ def get_base_url():
 
 
 class LaunchableClient:
-    def __init__(self, token, base_url="", http=requests):
+    def __init__(self, token: str, base_url: str = "", session: requests.Session = requests.Session()):
         self.base_url = base_url or get_base_url()
-        self.http = http
+        self.session = session
         self.token = token
 
     def request(self, method, path, **kwargs):
@@ -23,10 +23,10 @@ class LaunchableClient:
         url = self.base_url + path
         if 'timeout' not in kwargs:
             # (connection timeout, read timeout) in seconds
-            kwargs['timeout'] = (5,60)
+            kwargs['timeout'] = (5, 60)
 
         try:
-            return self.http.request(method, url, headers={**headers, **self._headers()}, **kwargs)
+            return self.session.request(method, url, headers={**headers, **self._headers()}, **kwargs)
         except Exception as e:
             raise Exception("unable to post to %s" % url) from e
 
